Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 18493)
+++ wp-includes/comment-template.php	(working copy)
@@ -831,7 +831,7 @@
  * and the post ID respectively.
  *
  * The $file path is passed through a filter hook called, 'comments_template'
- * which includes the TEMPLATEPATH and $file combined. Tries the $filtered path
+ * which includes the template path and $file combined. Tries the $filtered path
  * first and if it fails it will require the default comment themplate from the
  * default theme. If either does not exist, then the WordPress process will be
  * halted. It is advised for that reason, that the default theme is not deleted.
@@ -908,11 +908,11 @@
 	if ( !defined('COMMENTS_TEMPLATE') || !COMMENTS_TEMPLATE)
 		define('COMMENTS_TEMPLATE', true);
 
-	$include = apply_filters('comments_template', STYLESHEETPATH . $file );
+	$include = apply_filters('comments_template', get_stylesheet_directory() . $file );
 	if ( file_exists( $include ) )
 		require( $include );
-	elseif ( file_exists( TEMPLATEPATH . $file ) )
-		require( TEMPLATEPATH .  $file );
+	elseif ( file_exists( get_template_directory() . $file ) )
+		require( get_template_directory() .  $file );
 	else // Backward compat code will be removed in a future release
 		require( ABSPATH . WPINC . '/theme-compat/comments.php');
 }
Index: wp-settings.php
===================================================================
--- wp-settings.php	(revision 18493)
+++ wp-settings.php	(working copy)
@@ -278,10 +278,10 @@
 
 // Load the functions for the active theme, for both parent and child theme if applicable.
 if ( ! defined( 'WP_INSTALLING' ) || 'wp-activate.php' === $pagenow ) {
-	if ( TEMPLATEPATH !== STYLESHEETPATH && file_exists( STYLESHEETPATH . '/functions.php' ) )
-		include( STYLESHEETPATH . '/functions.php' );
-	if ( file_exists( TEMPLATEPATH . '/functions.php' ) )
-		include( TEMPLATEPATH . '/functions.php' );
+	if ( get_template_directory() !== get_stylesheet_directory() && file_exists( get_stylesheet_directory() . '/functions.php' ) )
+		include( get_stylesheet_directory() . '/functions.php' );
+	if ( file_exists( get_template_directory() . '/functions.php' ) )
+		include( get_template_directory() . '/functions.php' );
 }
 
 do_action( 'after_setup_theme' );

Index: wp-includes/theme.php
===================================================================
--- wp-includes/theme.php	(revision 18493)
+++ wp-includes/theme.php	(working copy)
@@ -14,7 +14,7 @@
  * @return bool true if a child theme is in use, false otherwise.
  **/
 function is_child_theme() {
-	return ( TEMPLATEPATH !== STYLESHEETPATH );
+	return ( get_template_directory() !== get_stylesheet_directory() );
 }
 
 /**
@@ -1062,7 +1062,7 @@
 /**
  * Retrieve the name of the highest priority template file that exists.
  *
  * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
  * inherit from a parent theme can just overload one file.
  *
  * @since 2.7.0
@@ -1077,11 +1077,11 @@
 	foreach ( (array) $template_names as $template_name ) {
 		if ( !$template_name )
 			continue;
-		if ( file_exists(STYLESHEETPATH . '/' . $template_name)) {
-			$located = STYLESHEETPATH . '/' . $template_name;
+		if ( file_exists(get_stylesheet_directory() . '/' . $template_name)) {
+			$located = get_stylesheet_directory() . '/' . $template_name;
 			break;
-		} else if ( file_exists(TEMPLATEPATH . '/' . $template_name) ) {
-			$located = TEMPLATEPATH . '/' . $template_name;
+		} else if ( file_exists(get_template_directory() . '/' . $template_name) ) {
+			$located = get_template_directory() . '/' . $template_name;
 			break;
 		}
 	}
@@ -1062,7 +1062,7 @@
  * Retrieve the name of the highest priority template file that exists.
  *
- * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
+ * Searches in the stylesheet path before template path so that themes which
  * inherit from a parent theme can just overload one file.
  *